@@ -12,16 +12,18 @@
 #include "avc_sidtab.h"
 #include "avc_internal.h"
 
-static inline unsigned sidtab_hash(security_context_t key) {
+static inline unsigned sidtab_hash(security_context_t key)
+{
 	char *p, *keyp;
 	unsigned int size;
 	unsigned int val;
 
 	val = 0;
-	keyp = (char*)key;
+	keyp = (char *)key;
 	size = strlen(keyp);
 	for (p = keyp; (unsigned int)(p - keyp) < size; p++)
-		val = (val << 4 | (val >> (8*sizeof(unsigned int)-4))) ^ (*p);
+		val =
+		    (val << 4 | (val >> (8 * sizeof(unsigned int) - 4))) ^ (*p);
 	return val & (SIDTAB_SIZE - 1);
 }
 
@@ -30,7 +32,7 @@ int sidtab_init(struct sidtab *s)
 	int i, rc = 0;
 
 	s->htable = (struct sidtab_node **)avc_malloc
-	  (sizeof(struct sidtab_node *) * SIDTAB_SIZE);
+	    (sizeof(struct sidtab_node *) * SIDTAB_SIZE);
 
 	if (!s->htable) {
 		rc = -1;
@@ -39,23 +41,22 @@ int sidtab_init(struct sidtab *s)
 	for (i = 0; i < SIDTAB_SIZE; i++)
 		s->htable[i] = NULL;
 	s->nel = 0;
- out:
+      out:
 	return rc;
 }
 
-int 
-sidtab_insert(struct sidtab *s, security_context_t ctx)
+int sidtab_insert(struct sidtab *s, security_context_t ctx)
 {
-        int hvalue, rc = 0;
+	int hvalue, rc = 0;
 	struct sidtab_node *newnode;
 	security_context_t newctx;
 
-	newnode = (struct sidtab_node*)avc_malloc(sizeof(*newnode));
+	newnode = (struct sidtab_node *)avc_malloc(sizeof(*newnode));
 	if (!newnode) {
 		rc = -1;
 		goto out;
 	}
-	newctx = (security_context_t)strdup(ctx);
+	newctx = (security_context_t) strdup(ctx);
 	if (!newctx) {
 		rc = -1;
 		avc_free(newnode);
@@ -65,81 +66,78 @@ sidtab_insert(struct sidtab *s, security_context_t ctx)
 	hvalue = sidtab_hash(newctx);
 	newnode->next = s->htable[hvalue];
 	newnode->sid_s.ctx = newctx;
-	newnode->sid_s.refcnt = 0;     /* caller should increment */
+	newnode->sid_s.refcnt = 0;	/* caller should increment */
 	s->htable[hvalue] = newnode;
 	s->nel++;
- out:
+      out:
 	return rc;
 }
 
-void
-sidtab_remove(struct sidtab *s, security_id_t sid)
+void sidtab_remove(struct sidtab *s, security_id_t sid)
 {
-        int hvalue;
+	int hvalue;
 	struct sidtab_node *cur, *prev;
 
 	hvalue = sidtab_hash(sid->ctx);
 	cur = s->htable[hvalue];
 	prev = NULL;
 	while (cur) {
-	  if (sid == &cur->sid_s) {
-	    if (prev)
-	      prev->next = cur->next;
-	    else
-	      s->htable[hvalue] = cur->next;
-	    avc_free(cur);
-	    s->nel--;
-	    return;
-	  } else {
-	    prev = cur;
-	    cur = cur->next;
-	  }
+		if (sid == &cur->sid_s) {
+			if (prev)
+				prev->next = cur->next;
+			else
+				s->htable[hvalue] = cur->next;
+			avc_free(cur);
+			s->nel--;
+			return;
+		} else {
+			prev = cur;
+			cur = cur->next;
+		}
 	}
 }
 
-security_id_t 
-sidtab_claim_sid(struct sidtab *s)
+security_id_t sidtab_claim_sid(struct sidtab *s)
 {
-  int i;
-  struct sidtab_node *cur;
+	int i;
+	struct sidtab_node *cur;
 
-  for (i=0; i < SIDTAB_SIZE; i++) {
-    cur = s->htable[i];
-    while (cur) {
-      if (!cur->sid_s.refcnt)
-	return &cur->sid_s;
-      cur = cur->next;
-    }
-  }
-  return NULL;
+	for (i = 0; i < SIDTAB_SIZE; i++) {
+		cur = s->htable[i];
+		while (cur) {
+			if (!cur->sid_s.refcnt)
+				return &cur->sid_s;
+			cur = cur->next;
+		}
+	}
+	return NULL;
 }
 
-int 
+int
 sidtab_context_to_sid(struct sidtab *s,
-		      security_context_t ctx,
-		      security_id_t *sid)
+		      security_context_t ctx, security_id_t * sid)
 {
-  int hvalue, rc = 0;
-  struct sidtab_node *cur;
+	int hvalue, rc = 0;
+	struct sidtab_node *cur;
 
-  *sid = NULL;
-  hvalue = sidtab_hash(ctx);
+	*sid = NULL;
+	hvalue = sidtab_hash(ctx);
 
- loop:
-  cur = s->htable[hvalue];
-  while (cur != NULL && strcmp(cur->sid_s.ctx, ctx)) 
-    cur = cur->next;
+      loop:
+	cur = s->htable[hvalue];
+	while (cur != NULL && strcmp(cur->sid_s.ctx, ctx))
+		cur = cur->next;
 
-  if (cur == NULL) {   /* need to make a new entry */
-    rc = sidtab_insert(s, ctx);
-    if (rc) 
-      goto out;
-    goto loop;         /* find the newly inserted node */
-  }
-  
-  *sid = &cur->sid_s;
- out:
-  return rc;
+	if (cur == NULL) {	/* need to make a new entry */
+		rc = sidtab_insert(s, ctx);
+		if (rc)
+			goto out;
+		goto loop;	/* find the newly inserted node */
+	}
+
+	*sid = &cur->sid_s;
+      out:
+	return rc;
 }
 
 void sidtab_sid_stats(struct sidtab *h, char *buf, int buflen)
@@ -166,7 +164,7 @@ void sidtab_sid_stats(struct sidtab *h, char *buf, int buflen)
 
 	snprintf(buf, buflen,
 		 "%s:  %d SID entries and %d/%d buckets used, longest "
-		 "chain length %d\n", avc_prefix, h->nel, slots_used, 
+		 "chain length %d\n", avc_prefix, h->nel, slots_used,
 		 SIDTAB_SIZE, max_chain_len);
 }
 
