@@ -5,7 +5,6 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <limits.h>
-#include <asm/page.h>
 #include <stdio.h>
 #include "policy.h"
 
@@ -22,13 +21,13 @@ int is_selinux_enabled(void)
 	if (fd < 0)
 		return -1;
 
-	size = PAGE_SIZE;
+	size = selinux_page_size;
 	buf = malloc(size);
 	if (!buf) {
 		enabled = -1;
 		goto out;
 	}
-		
+
 	memset(buf, 0, size);
 
 	ret = read(fd, buf, size - 1);
@@ -47,12 +46,13 @@ int is_selinux_enabled(void)
 			enabled = 0;
 		freecon(con);
 	}
-out2:
+      out2:
 	free(buf);
-out:
+      out:
 	close(fd);
 	return enabled;
 }
+
 hidden_def(is_selinux_enabled)
 
 /*
@@ -65,6 +65,9 @@ int is_selinux_mls_enabled(void)
 	char buf[20], path[PATH_MAX];
 	int fd, ret, enabled = 0;
 
+	if (!selinux_mnt)
+		return enabled;
+
 	snprintf(path, sizeof path, "%s/mls", selinux_mnt);
 	fd = open(path, O_RDONLY);
 	if (fd < 0)
@@ -72,7 +75,7 @@ int is_selinux_mls_enabled(void)
 
 	memset(buf, 0, sizeof buf);
 
-	ret = read(fd, buf, sizeof buf-1);
+	ret = read(fd, buf, sizeof buf - 1);
 	close(fd);
 	if (ret < 0)
 		return enabled;
@@ -82,4 +85,5 @@ int is_selinux_mls_enabled(void)
 
 	return enabled;
 }
+
 hidden_def(is_selinux_mls_enabled)
