@@ -7,19 +7,19 @@
 #include "selinux_internal.h"
 #include "policy.h"
 
-int lgetfilecon_raw(const char *path, security_context_t *context)
+int lgetfilecon_raw(const char *path, security_context_t * context)
 {
 	char *buf;
 	ssize_t size;
 	ssize_t ret;
 
-	size = INITCONTEXTLEN+1;
+	size = INITCONTEXTLEN + 1;
 	buf = malloc(size);
-	if (!buf) 
+	if (!buf)
 		return -1;
 	memset(buf, 0, size);
 
-	ret = lgetxattr(path, XATTR_NAME_SELINUX, buf, size-1);
+	ret = lgetxattr(path, XATTR_NAME_SELINUX, buf, size - 1);
 	if (ret < 0 && errno == ERANGE) {
 		char *newbuf;
 
@@ -34,32 +34,31 @@ int lgetfilecon_raw(const char *path, security_context_t *context)
 
 		buf = newbuf;
 		memset(buf, 0, size);
-		ret = lgetxattr(path, XATTR_NAME_SELINUX, buf, size-1); 
+		ret = lgetxattr(path, XATTR_NAME_SELINUX, buf, size - 1);
 	}
-out:			
+      out:
 	if (ret < 0)
 		free(buf);
 	else
 		*context = buf;
 	return ret;
 }
+
 hidden_def(lgetfilecon_raw)
 
-int lgetfilecon(const char *path, security_context_t *context)
+int lgetfilecon(const char *path, security_context_t * context)
 {
 	int ret;
 	security_context_t rcontext;
 
- 	ret = lgetfilecon_raw(path, &rcontext);
+	ret = lgetfilecon_raw(path, &rcontext);
 
-	if (context_translations && ret > 0) {
-		if (raw_to_trans_context(rcontext, context)) {
-			*context = NULL;
-			ret = -1;
-		}
+	if (ret > 0) {
+		ret = selinux_raw_to_trans_context(rcontext, context);
 		freecon(rcontext);
-	} else if (ret > 0)
-		*context = rcontext;
+	}
 
+	if (ret >= 0 && *context)
+		return strlen(*context) + 1;
 	return ret;
 }
