@@ -19,10 +19,15 @@ int security_load_policy(void *data, size_t len)
 {
 	char path[PATH_MAX];
 	int fd, ret;
-	
+
+	if (!selinux_mnt) {
+		errno = ENOENT;
+		return -1;
+	}
+
 	snprintf(path, sizeof path, "%s/load", selinux_mnt);
 	fd = open(path, O_RDWR);
-	if (fd < 0) 
+	if (fd < 0)
 		return -1;
 
 	ret = write(fd, data, len);
@@ -31,6 +36,7 @@ int security_load_policy(void *data, size_t len)
 		return -1;
 	return 0;
 }
+
 hidden_def(security_load_policy)
 
 int load_setlocaldefs hidden = 1;
@@ -47,13 +53,14 @@ int selinux_mkload_policy(int preservebools)
 	sepol_policydb_t *policydb;
 	sepol_policy_file_t *pf;
 
-search:
-	snprintf(path, sizeof(path), "%s.%d", 
+      search:
+	snprintf(path, sizeof(path), "%s.%d",
 		 selinux_binary_policy_path(), vers);
 	fd = open(path, O_RDONLY);
-	while (fd < 0 && errno == ENOENT && --vers >= sepol_policy_kern_vers_min()) {
+	while (fd < 0 && errno == ENOENT
+	       && --vers >= sepol_policy_kern_vers_min()) {
 		/* Check prior versions to see if old policy is available */
-		snprintf(path, sizeof(path), "%s.%d", 
+		snprintf(path, sizeof(path), "%s.%d",
 			 selinux_binary_policy_path(), vers);
 		fd = open(path, O_RDONLY);
 	}
@@ -64,12 +71,12 @@ search:
 		goto close;
 
 	prot = PROT_READ;
-	if (load_setlocaldefs || preservebools) 
+	if (load_setlocaldefs || preservebools)
 		prot |= PROT_WRITE;
 
 	size = sb.st_size;
 	data = map = mmap(NULL, size, prot, MAP_PRIVATE, fd, 0);
-	if (map == MAP_FAILED) 
+	if (map == MAP_FAILED)
 		goto close;
 
 	if (vers > kernvers) {
@@ -92,7 +99,7 @@ search:
 			sepol_policy_file_free(pf);
 			sepol_policydb_free(policydb);
 			munmap(map, sb.st_size);
-			close(fd);			
+			close(fd);
 			vers--;
 			goto search;
 		}
@@ -103,7 +110,8 @@ search:
 	if (load_setlocaldefs) {
 		void *olddata = data;
 		size_t oldsize = size;
-		rc = sepol_genusers(olddata, oldsize, selinux_users_path(), &data, &size);
+		rc = sepol_genusers(olddata, oldsize, selinux_users_path(),
+				    &data, &size);
 		if (rc < 0) {
 			/* Fall back to the prior image if genusers failed. */
 			data = olddata;
@@ -118,31 +126,35 @@ search:
 	if (preservebools) {
 		rc = security_get_boolean_names(&names, &len);
 		if (!rc) {
-			values = malloc(sizeof(int)*len);
+			values = malloc(sizeof(int) * len);
 			if (!values)
 				goto unmap;
 			for (i = 0; i < len; i++)
-				values[i] = security_get_boolean_active(names[i]);
-			(void) sepol_genbools_array(data, size, names, values, len);
+				values[i] =
+				    security_get_boolean_active(names[i]);
+			(void)sepol_genbools_array(data, size, names, values,
+						   len);
 			free(values);
 			for (i = 0; i < len; i++)
 				free(names[i]);
 			free(names);
 		}
 	} else if (load_setlocaldefs) {
-		(void) sepol_genbools(data, size, (char*)selinux_booleans_path());
+		(void)sepol_genbools(data, size,
+				     (char *)selinux_booleans_path());
 	}
 
 	rc = security_load_policy(data, size);
 
-unmap:
+      unmap:
 	if (data != map)
 		free(data);
 	munmap(map, sb.st_size);
-close:
+      close:
 	close(fd);
 	return rc;
 }
+
 hidden_def(selinux_mkload_policy)
 
 /*
@@ -154,12 +166,11 @@ hidden_def(selinux_mkload_policy)
  * required for the initial policy load.
  */
 #define SELINUXMNT "/selinux/"
-
 int selinux_init_load_policy(int *enforce)
 {
 	int rc = 0, orig_enforce = 0, seconfig = -2, secmdline = -1;
 	FILE *cfg;
-	char buf[4096];
+	char *buf;
 
 	/*
 	 * Get desired mode (disabled, permissive, enforcing) from 
@@ -172,13 +183,20 @@ int selinux_init_load_policy(int *enforce)
 	cfg = fopen("/proc/cmdline", "r");
 	if (cfg) {
 		char *tmp;
-		if (fgets(buf, 4096, cfg) && 
-		    (tmp = strstr(buf,"enforcing="))) {
-			if (tmp == buf || isspace(*(tmp-1))) {
-				secmdline = atoi(tmp+sizeof("enforcing=")-1);
+		buf = malloc(selinux_page_size);
+		if (!buf) {
+			fclose(cfg);
+			return -1;
+		}
+		if (fgets(buf, selinux_page_size, cfg) &&
+		    (tmp = strstr(buf, "enforcing="))) {
+			if (tmp == buf || isspace(*(tmp - 1))) {
+				secmdline =
+				    atoi(tmp + sizeof("enforcing=") - 1);
 			}
 		}
 		fclose(cfg);
+		free(buf);
 	}
 #define MNT_DETACH 2
 	if (rc == 0)
@@ -189,11 +207,11 @@ int selinux_init_load_policy(int *enforce)
 	 * Command line argument takes precedence, then config file. 
 	 */
 	if (secmdline >= 0)
-		*enforce = secmdline; 
+		*enforce = secmdline;
 	else if (seconfig >= 0)
 		*enforce = seconfig;
 	else
-		*enforce = 0; /* unspecified or disabled */
+		*enforce = 0;	/* unspecified or disabled */
 
 	/*
 	 * Check for the existence of SELinux via selinuxfs, and 
@@ -249,7 +267,7 @@ int selinux_init_load_policy(int *enforce)
 	/* Load the policy. */
 	return selinux_mkload_policy(0);
 
-noload:
+      noload:
 	/*
 	 * Only return 0 on a successful completion of policy load.
 	 * In any other case, we want to return an error so that init
