@@ -14,11 +14,11 @@
 #include "policy.h"
 #include "context_internal.h"
 
-static void 
+static void
 #ifdef __GNUC__
-__attribute__ ((format (printf, 1, 2)))
+    __attribute__ ((format(printf, 1, 2)))
 #endif
-default_printf(const char *fmt, ...) 
+    default_printf(const char *fmt, ...)
 {
 	va_list ap;
 	va_start(ap, fmt);
@@ -26,47 +26,13 @@ default_printf(const char *fmt, ...)
 	va_end(ap);
 }
 
-/* If MLS is disabled, strip any MLS level field from the context.
-   This allows file_contexts with MLS levels to be processed on
-   a non-MLS system that otherwise has the same policy. */
-static inline int STRIP_LEVEL(char **context, int mls_enabled)
-{
-	char *str;
-	context_t con;
-	int rc = -1;
-
-	if (mls_enabled)
-		return 0;
-
-	con = context_new(*context);
-	if (!con)
-		return rc;
-
-	if (context_range_set(con,NULL))
-		goto out;
-
-	str = context_str(con);
-	if (!str)
-		goto out;
-
-	str = strdup(str);
-	if (!str)
-		goto out;
-
-	free(*context);
-	*context = str;
-	rc = 0;
-out:
-	context_free(con);
-	return rc;
-}
-static void 
+static void
 #ifdef __GNUC__
-__attribute__ ((format (printf, 1, 2)))
+    __attribute__ ((format(printf, 1, 2)))
 #endif
-(*myprintf)(const char *fmt, ...) = &default_printf;
+    (*myprintf) (const char *fmt,...) = &default_printf;
 
-void set_matchpathcon_printf(void (*f)(const char *fmt, ...))
+void set_matchpathcon_printf(void (*f) (const char *fmt, ...))
 {
 	if (f)
 		myprintf = f;
@@ -74,9 +40,9 @@ void set_matchpathcon_printf(void (*f)(const char *fmt, ...))
 		myprintf = &default_printf;
 }
 
-static int (*myinvalidcon)(const char *p, unsigned l, char *c) = NULL;
+static int (*myinvalidcon) (const char *p, unsigned l, char *c) = NULL;
 
-void set_matchpathcon_invalidcon(int (*f)(const char *p, unsigned l, char *c))
+void set_matchpathcon_invalidcon(int (*f) (const char *p, unsigned l, char *c))
 {
 	myinvalidcon = f;
 }
@@ -84,11 +50,12 @@ void set_matchpathcon_invalidcon(int (*f)(const char *p, unsigned l, char *c))
 static int default_canoncon(const char *path, unsigned lineno, char **context)
 {
 	char *tmpcon;
-	if (security_canonicalize_context(*context, &tmpcon) < 0) {
+	if (security_canonicalize_context_raw(*context, &tmpcon) < 0) {
 		if (errno == ENOENT)
 			return 0;
 		if (lineno)
-			myprintf("%s:  line %u has invalid context %s\n", path, lineno, *context);
+			myprintf("%s:  line %u has invalid context %s\n", path,
+				 lineno, *context);
 		else
 			myprintf("%s:  invalid context %s\n", path, *context);
 		return 1;
@@ -98,9 +65,10 @@ static int default_canoncon(const char *path, unsigned lineno, char **context)
 	return 0;
 }
 
-static int (*mycanoncon)(const char *p, unsigned l, char **c) = &default_canoncon;
+static int (*mycanoncon) (const char *p, unsigned l, char **c) =
+    &default_canoncon;
 
-void set_matchpathcon_canoncon(int (*f)(const char *p, unsigned l, char **c))
+void set_matchpathcon_canoncon(int (*f) (const char *p, unsigned l, char **c))
 {
 	if (f)
 		mycanoncon = f;
@@ -108,7 +76,7 @@ void set_matchpathcon_canoncon(int (*f)(const char *p, unsigned l, char **c))
 		mycanoncon = &default_canoncon;
 }
 
-static unsigned int myflags;
+static __thread unsigned int myflags;
 
 void set_matchpathcon_flags(unsigned int flags)
 {
@@ -122,11 +90,12 @@ typedef struct spec {
 	char *regex_str;	/* regular expession string for diagnostic messages */
 	char *type_str;		/* type string for diagnostic messages */
 	char *context;		/* context string */
-	int context_valid;      /* context string has been validated/canonicalized */
+	int context_valid;	/* context string has been validated/canonicalized */
+	int translated;		/* context string has been translated */
 	regex_t regex;		/* compiled regular expression */
 	mode_t mode;		/* mode format value */
 	int matches;		/* number of matching pathnames */
-	int hasMetaChars; 	/* indicates whether the RE has 
+	int hasMetaChars;	/* indicates whether the RE has 
 				   any meta characters.  
 				   0 = no meta chars 
 				   1 = has one or more meta chars */
@@ -143,32 +112,31 @@ static stem_t *stem_arr = NULL;
 static int num_stems = 0;
 static int alloc_stems = 0;
 
-static const char * const regex_chars = ".^$?*+|[({";
+static const char *const regex_chars = ".^$?*+|[({";
 
 /* Return the length of the text that can be considered the stem, returns 0
  * if there is no identifiable stem */
-static int get_stem_from_spec(const char * const buf)
+static int get_stem_from_spec(const char *const buf)
 {
 	const char *tmp = strchr(buf + 1, '/');
 	const char *ind;
 
-	if(!tmp)
+	if (!tmp)
 		return 0;
 
-	for(ind = buf; ind < tmp; ind++)
-	{
-		if(strchr(regex_chars, (int)*ind))
+	for (ind = buf; ind < tmp; ind++) {
+		if (strchr(regex_chars, (int)*ind))
 			return 0;
 	}
 	return tmp - buf;
 }
 
 /* return the length of the text that is the stem of a file name */
-static int get_stem_from_file_name(const char * const buf)
+static int get_stem_from_file_name(const char *const buf)
 {
 	const char *tmp = strchr(buf + 1, '/');
 
-	if(!tmp)
+	if (!tmp)
 		return 0;
 	return tmp - buf;
 }
@@ -182,28 +150,26 @@ static int find_stem_from_spec(const char **buf)
 	int i;
 	int stem_len = get_stem_from_spec(*buf);
 
-	if(!stem_len)
+	if (!stem_len)
 		return -1;
-	for(i = 0; i < num_stems; i++)
-	{
-		if(stem_len == stem_arr[i].len && !strncmp(*buf, stem_arr[i].buf, stem_len))
-		{
+	for (i = 0; i < num_stems; i++) {
+		if (stem_len == stem_arr[i].len
+		    && !strncmp(*buf, stem_arr[i].buf, stem_len)) {
 			*buf += stem_len;
 			return i;
 		}
 	}
-	if(num_stems == alloc_stems)
-	{
+	if (num_stems == alloc_stems) {
 		stem_t *tmp_arr;
 		alloc_stems = alloc_stems * 2 + 16;
 		tmp_arr = realloc(stem_arr, sizeof(stem_t) * alloc_stems);
-		if(!tmp_arr)
+		if (!tmp_arr)
 			return -1;
 		stem_arr = tmp_arr;
 	}
 	stem_arr[num_stems].len = stem_len;
 	stem_arr[num_stems].buf = malloc(stem_len + 1);
-	if(!stem_arr[num_stems].buf)
+	if (!stem_arr[num_stems].buf)
 		return -1;
 	memcpy(stem_arr[num_stems].buf, *buf, stem_len);
 	stem_arr[num_stems].buf[stem_len] = '\0';
@@ -220,12 +186,11 @@ static int find_stem_from_file(const char **buf)
 	int i;
 	int stem_len = get_stem_from_file_name(*buf);
 
-	if(!stem_len)
+	if (!stem_len)
 		return -1;
-	for(i = 0; i < num_stems; i++)
-	{
-		if(stem_len == stem_arr[i].len && !strncmp(*buf, stem_arr[i].buf, stem_len))
-		{
+	for (i = 0; i < num_stems; i++) {
+		if (stem_len == stem_arr[i].len
+		    && !strncmp(*buf, stem_arr[i].buf, stem_len)) {
 			*buf += stem_len;
 			return i;
 		}
@@ -277,10 +242,10 @@ int matchpathcon_filespec_add(ino_t ino, int specind, const char *file)
 	struct stat sb;
 
 	if (!fl_head) {
-		fl_head = malloc(sizeof(file_spec_t)*HASH_BUCKETS);
+		fl_head = malloc(sizeof(file_spec_t) * HASH_BUCKETS);
 		if (!fl_head)
 			goto oom;
-		memset(fl_head, 0, sizeof(file_spec_t)*HASH_BUCKETS);
+		memset(fl_head, 0, sizeof(file_spec_t) * HASH_BUCKETS);
 	}
 
 	h = (ino + (ino >> HASH_BITS)) & HASH_MASK;
@@ -299,17 +264,21 @@ int matchpathcon_filespec_add(ino_t ino, int specind, const char *file)
 
 			}
 
-			no_conflict = (strcmp(spec_arr[fl->specind].context,spec_arr[specind].context) == 0);
+			no_conflict =
+			    (strcmp
+			     (spec_arr[fl->specind].context,
+			      spec_arr[specind].context) == 0);
 			if (no_conflict)
 				return fl->specind;
 
-			myprintf("%s:  conflicting specifications for %s and %s, using %s.\n",
-				__FUNCTION__, file, fl->file,
-				((specind > fl->specind) ? spec_arr[specind].
-				 context : spec_arr[fl->specind].context));
+			myprintf
+			    ("%s:  conflicting specifications for %s and %s, using %s.\n",
+			     __FUNCTION__, file, fl->file,
+			     ((specind >
+			       fl->specind) ? spec_arr[specind].
+			      context : spec_arr[fl->specind].context));
 			fl->specind =
-			    (specind >
-			     fl->specind) ? specind : fl->specind;
+			    (specind > fl->specind) ? specind : fl->specind;
 			free(fl->file);
 			fl->file = malloc(strlen(file) + 1);
 			if (!fl->file)
@@ -334,9 +303,9 @@ int matchpathcon_filespec_add(ino_t ino, int specind, const char *file)
 	fl->next = prevfl->next;
 	prevfl->next = fl;
 	return fl->specind;
-oom_freefl:
+      oom_freefl:
 	free(fl);
-oom:
+      oom:
 	myprintf("%s:  insufficient memory for file label entry for %s\n",
 		 __FUNCTION__, file);
 	return -1;
@@ -408,22 +377,23 @@ static void nodups_specs(const char *path)
 
 	for (ii = 0; ii < nspec; ii++) {
 		curr_spec = &spec_arr[ii];
-		for (jj = ii + 1; jj < nspec; jj++) { 
-			if ((!strcmp(spec_arr[jj].regex_str, curr_spec->regex_str))
-									&&
-				(!spec_arr[jj].mode || !curr_spec->mode 
-				 || spec_arr[jj].mode == curr_spec->mode)) {
-				if (strcmp(spec_arr[jj].context, curr_spec->context)) {
-					myprintf(
-					"%s: Multiple different specifications for %s  (%s and %s).\n",
-						path, curr_spec->regex_str, 
-						spec_arr[jj].context,
-						curr_spec->context);
-				}
-				else {
-					myprintf(
-					"%s: Multiple same specifications for %s.\n",
-						path, curr_spec->regex_str);
+		for (jj = ii + 1; jj < nspec; jj++) {
+			if ((!strcmp
+			     (spec_arr[jj].regex_str, curr_spec->regex_str))
+			    && (!spec_arr[jj].mode || !curr_spec->mode
+				|| spec_arr[jj].mode == curr_spec->mode)) {
+				if (strcmp
+				    (spec_arr[jj].context,
+				     curr_spec->context)) {
+					myprintf
+					    ("%s: Multiple different specifications for %s  (%s and %s).\n",
+					     path, curr_spec->regex_str,
+					     spec_arr[jj].context,
+					     curr_spec->context);
+				} else {
+					myprintf
+					    ("%s: Multiple same specifications for %s.\n",
+					     path, curr_spec->regex_str);
 				}
 			}
 		}
@@ -441,36 +411,38 @@ static void spec_hasMetaChars(struct spec *spec)
 	len = strlen(spec->regex_str);
 	end = c + len;
 
-	spec->hasMetaChars = 0; 
+	spec->hasMetaChars = 0;
 
 	/* Look at each character in the RE specification string for a 
 	 * meta character. Return when any meta character reached. */
 	while (c != end) {
-		switch(*c) {
-			case '.':
-			case '^':
-			case '$':
-			case '?':
-			case '*':
-			case '+':
-			case '|':
-			case '[':
-			case '(':
-			case '{':
-				spec->hasMetaChars = 1;
-				return;
-			case '\\':		/* skip the next character */
-				c++;
-				break;
-			default:
-				break;
+		switch (*c) {
+		case '.':
+		case '^':
+		case '$':
+		case '?':
+		case '*':
+		case '+':
+		case '|':
+		case '[':
+		case '(':
+		case '{':
+			spec->hasMetaChars = 1;
+			return;
+		case '\\':	/* skip the next character */
+			c++;
+			break;
+		default:
+			break;
 
 		}
 		c++;
 	}
 	return;
 }
-static int process_line( const char *path, const char *prefix, char *line_buf, int pass, unsigned lineno, int mls_enabled) {
+static int process_line(const char *path, const char *prefix, char *line_buf,
+			int pass, unsigned lineno)
+{
 	int items, len, regerr;
 	char *buf_p;
 	char *regex, *type, *context;
@@ -485,11 +457,10 @@ static int process_line( const char *path, const char *prefix, char *line_buf, i
 	/* Skip comment lines and empty lines. */
 	if (*buf_p == '#' || *buf_p == 0)
 		return 0;
-	items =
-		sscanf(line_buf, "%as %as %as", &regex, &type,
-		       &context);
+	items = sscanf(line_buf, "%as %as %as", &regex, &type, &context);
 	if (items < 2) {
-		myprintf("%s:  line %d is missing fields, skipping\n", path, lineno); 
+		myprintf("%s:  line %d is missing fields, skipping\n", path,
+			 lineno);
 		return 0;
 	} else if (items == 2) {
 		/* The type field is optional. */
@@ -513,7 +484,7 @@ static int process_line( const char *path, const char *prefix, char *line_buf, i
 		char *cp;
 		spec_arr[nspec].stem_id = find_stem_from_spec(&reg_buf);
 		spec_arr[nspec].regex_str = regex;
-		
+
 		/* Anchor the regular expression. */
 		len = strlen(reg_buf);
 		cp = anchored_regex = malloc(len + 3);
@@ -524,29 +495,30 @@ static int process_line( const char *path, const char *prefix, char *line_buf, i
 		cp = mempcpy(cp, reg_buf, len);
 		*cp++ = '$';
 		*cp = '\0';
-		
+
 		/* Compile the regular expression. */
 		regerr =
-			regcomp(&spec_arr[nspec].regex,
-				anchored_regex,
-				REG_EXTENDED | REG_NOSUB);
+		    regcomp(&spec_arr[nspec].regex,
+			    anchored_regex, REG_EXTENDED | REG_NOSUB);
 		if (regerr != 0) {
 			size_t errsz = 0;
 			char *errbuf = NULL;
-			errsz = regerror(regerr, &spec_arr[nspec].regex, 
+			errsz = regerror(regerr, &spec_arr[nspec].regex,
 					 errbuf, errsz);
 			if (errsz)
 				errbuf = malloc(errsz);
 			if (errbuf)
-				(void) regerror(regerr, 
-						&spec_arr[nspec].regex, 
-						errbuf, errsz);
-			myprintf("%s:  line %d has invalid regex %s:  %s\n", path, lineno, anchored_regex, (errbuf ? errbuf : "out of memory")); 
+				(void)regerror(regerr,
+					       &spec_arr[nspec].regex,
+					       errbuf, errsz);
+			myprintf("%s:  line %d has invalid regex %s:  %s\n",
+				 path, lineno, anchored_regex,
+				 (errbuf ? errbuf : "out of memory"));
 			free(anchored_regex);
 			return 0;
 		}
 		free(anchored_regex);
-		
+
 		/* Convert the type string to a mode format */
 		spec_arr[nspec].type_str = type;
 		spec_arr[nspec].mode = 0;
@@ -554,7 +526,8 @@ static int process_line( const char *path, const char *prefix, char *line_buf, i
 			goto skip_type;
 		len = strlen(type);
 		if (type[0] != '-' || len != 2) {
-			myprintf("%s:  line %d has invalid file type %s\n", path, lineno, type); 
+			myprintf("%s:  line %d has invalid file type %s\n",
+				 path, lineno, type);
 			return 0;
 		}
 		switch (type[1]) {
@@ -580,36 +553,17 @@ static int process_line( const char *path, const char *prefix, char *line_buf, i
 			spec_arr[nspec].mode = S_IFREG;
 			break;
 		default:
-			myprintf("%s:  line %d has invalid file type %s\n", path, lineno, type); 
+			myprintf("%s:  line %d has invalid file type %s\n",
+				 path, lineno, type);
 			return 0;
 		}
-		
-	skip_type:
+
+	      skip_type:
 		if (strcmp(context, "<<none>>")) {
-			char *tmpcon = NULL;
-
-			if (myflags & MATCHPATHCON_NOTRANS)
-				goto skip_trans;
-
-			if (context_translations) {
-				if (raw_to_trans_context(context, &tmpcon)) {
-					myprintf("%s: line %u has invalid "
-					         "context %s\n",
-					         path, lineno, context);
-					return 0;
-				}
-				free(context);
-				context = tmpcon;
-			} else {
-				if (STRIP_LEVEL(&context, mls_enabled))
-					return -1;
-			}
-
-skip_trans:
 			if (myflags & MATCHPATHCON_VALIDATE) {
 				if (myinvalidcon) {
 					/* Old-style validation of context. */
-					if (myinvalidcon(path, lineno, context)) 
+					if (myinvalidcon(path, lineno, context))
 						return 0;
 				} else {
 					/* New canonicalization of context. */
@@ -621,12 +575,12 @@ skip_trans:
 		}
 
 		spec_arr[nspec].context = context;
-		
+
 		/* Determine if specification has 
 		 * any meta characters in the RE */
 		spec_hasMetaChars(&spec_arr[nspec]);
 	}
-	
+
 	nspec++;
 	if (pass == 0) {
 		free(regex);
@@ -647,9 +601,9 @@ int matchpathcon_init_prefix(const char *path, const char *prefix)
 	char *line_buf = NULL;
 	size_t line_len = 0;
 	unsigned int lineno, pass, i, j, maxnspec;
-	spec_t *spec_copy=NULL;
-	int status=-1;
-	int mls_enabled=is_selinux_mls_enabled();
+	spec_t *spec_copy = NULL;
+	int status = -1;
+	struct stat sb;
 
 	/* Open the specification file. */
 	if (!path)
@@ -658,8 +612,16 @@ int matchpathcon_init_prefix(const char *path, const char *prefix)
 		return -1;
 	__fsetlocking(fp, FSETLOCKING_BYCALLER);
 
+	if (fstat(fileno(fp), &sb) < 0)
+		return -1;
+	if (!S_ISREG(sb.st_mode)) {
+		errno = EINVAL;
+		return -1;
+	}
+
 	if ((myflags & MATCHPATHCON_BASEONLY) == 0) {
-		snprintf(homedir_path, sizeof(homedir_path), "%s.homedirs", path);
+		snprintf(homedir_path, sizeof(homedir_path), "%s.homedirs",
+			 path);
 		homedirfp = fopen(homedir_path, "r");
 		if (homedirfp != NULL)
 			__fsetlocking(homedirfp, FSETLOCKING_BYCALLER);
@@ -682,21 +644,29 @@ int matchpathcon_init_prefix(const char *path, const char *prefix)
 	for (pass = 0; pass < 2; pass++) {
 		lineno = 0;
 		nspec = 0;
-		while (getline(&line_buf, &line_len, fp) > 0 && nspec < maxnspec) {
-			if (process_line(path, prefix, line_buf, pass, ++lineno, mls_enabled) != 0)
+		while (getline(&line_buf, &line_len, fp) > 0
+		       && nspec < maxnspec) {
+			if (process_line(path, prefix, line_buf, pass, ++lineno)
+			    != 0)
 				goto finish;
 		}
 		lineno = 0;
-		if (homedirfp) 
-			while (getline(&line_buf, &line_len, homedirfp) > 0 && nspec < maxnspec) {
-				if (process_line(homedir_path, prefix, line_buf, pass, ++lineno, mls_enabled) != 0)
+		if (homedirfp)
+			while (getline(&line_buf, &line_len, homedirfp) > 0
+			       && nspec < maxnspec) {
+				if (process_line
+				    (homedir_path, prefix, line_buf, pass,
+				     ++lineno) != 0)
 					goto finish;
 			}
 
 		lineno = 0;
-		if (localfp) 
-			while (getline(&line_buf, &line_len, localfp) > 0 && nspec < maxnspec) {
-				if (process_line(local_path, prefix, line_buf, pass, ++lineno, mls_enabled) != 0)
+		if (localfp)
+			while (getline(&line_buf, &line_len, localfp) > 0
+			       && nspec < maxnspec) {
+				if (process_line
+				    (local_path, prefix, line_buf, pass,
+				     ++lineno) != 0)
 					goto finish;
 			}
 
@@ -705,14 +675,15 @@ int matchpathcon_init_prefix(const char *path, const char *prefix)
 				status = 0;
 				goto finish;
 			}
-			if ((spec_arr = malloc(sizeof(spec_t) * nspec)) ==
-			    NULL)
+			if ((spec_arr = malloc(sizeof(spec_t) * nspec)) == NULL)
 				goto finish;
 			memset(spec_arr, '\0', sizeof(spec_t) * nspec);
 			maxnspec = nspec;
 			rewind(fp);
-			if (homedirfp) rewind(homedirfp);
-			if (localfp) rewind(localfp);
+			if (homedirfp)
+				rewind(homedirfp);
+			if (localfp)
+				rewind(localfp);
 		}
 	}
 	free(line_buf);
@@ -736,13 +707,17 @@ int matchpathcon_init_prefix(const char *path, const char *prefix)
 	nodups_specs(path);
 
 	status = 0;
- finish:
+      finish:
 	fclose(fp);
-	if (spec_arr != spec_copy) free(spec_arr);
-	if (homedirfp) fclose(homedirfp);
-	if (localfp) fclose(localfp);
+	if (spec_arr != spec_copy)
+		free(spec_arr);
+	if (homedirfp)
+		fclose(homedirfp);
+	if (localfp)
+		fclose(localfp);
 	return status;
 }
+
 hidden_def(matchpathcon_init_prefix)
 
 int matchpathcon_init(const char *path)
@@ -750,8 +725,34 @@ int matchpathcon_init(const char *path)
 	return matchpathcon_init_prefix(path, NULL);
 }
 
-static int matchpathcon_common(const char *name, 
-			       mode_t mode)
+void matchpathcon_fini(void)
+{
+	struct spec *spec;
+	struct stem *stem;
+	unsigned int i;
+
+	for (i = 0; i < nspec; i++) {
+		spec = &spec_arr[i];
+		free(spec->regex_str);
+		free(spec->type_str);
+		free(spec->context);
+		regfree(&spec->regex);
+	}
+	free(spec_arr);
+	spec_arr = NULL;
+	nspec = 0;
+
+	for (i = 0; i < (unsigned int)num_stems; i++) {
+		stem = &stem_arr[i];
+		free(stem->buf);
+	}
+	free(stem_arr);
+	stem_arr = NULL;
+	num_stems = 0;
+	alloc_stems = 0;
+}
+
+static int matchpathcon_common(const char *name, mode_t mode)
 {
 	int i, ret, file_stem;
 	const char *buf = name;
@@ -774,19 +775,23 @@ static int matchpathcon_common(const char *name,
 	 * Check for matching specifications in reverse order, so that
 	 * the last matching specification is used.
 	 */
-	for (i = nspec - 1; i >= 0; i--)
-	{
+	for (i = nspec - 1; i >= 0; i--) {
 		/* if the spec in question matches no stem or has the same
 		 * stem as the file AND if the spec in question has no mode
 		 * specified or if the mode matches the file mode then we do
-		 * a regex check	*/
-		if( (spec_arr[i].stem_id == -1 || spec_arr[i].stem_id == file_stem)
-		  && (!mode || !spec_arr[i].mode || ( (mode & S_IFMT) == spec_arr[i].mode ) ) )
-		{
-			if(spec_arr[i].stem_id == -1)
-				ret = regexec(&spec_arr[i].regex, name, 0, NULL, 0);
+		 * a regex check        */
+		if ((spec_arr[i].stem_id == -1
+		     || spec_arr[i].stem_id == file_stem)
+		    && (!mode || !spec_arr[i].mode
+			|| ((mode & S_IFMT) == spec_arr[i].mode))) {
+			if (spec_arr[i].stem_id == -1)
+				ret =
+				    regexec(&spec_arr[i].regex, name, 0, NULL,
+					    0);
 			else
-				ret = regexec(&spec_arr[i].regex, buf, 0, NULL, 0);
+				ret =
+				    regexec(&spec_arr[i].regex, buf, 0, NULL,
+					    0);
 			if (ret == 0)
 				break;
 
@@ -809,9 +814,7 @@ static int matchpathcon_common(const char *name,
 
 }
 
-int matchpathcon(const char *name, 
-		 mode_t mode,
-		 security_context_t *con)
+int matchpathcon(const char *name, mode_t mode, security_context_t * con)
 {
 	int i = matchpathcon_common(name, mode);
 
@@ -826,30 +829,39 @@ int matchpathcon(const char *name,
 	if (!spec_arr[i].context_valid) {
 		if (myinvalidcon) {
 			/* Old-style validation of context. */
-			if (myinvalidcon("file_contexts", 0, spec_arr[i].context))
+			if (myinvalidcon
+			    ("file_contexts", 0, spec_arr[i].context))
 				goto bad;
 		} else {
 			/* New canonicalization of context. */
-			if (mycanoncon("file_contexts", 0, &spec_arr[i].context))
+			if (mycanoncon
+			    ("file_contexts", 0, &spec_arr[i].context))
 				goto bad;
 		}
 		spec_arr[i].context_valid = 1;
 	}
 
+	if (!spec_arr[i].translated && !(myflags & MATCHPATHCON_NOTRANS)) {
+		char *tmpcon = NULL;
+		if (selinux_raw_to_trans_context(spec_arr[i].context, &tmpcon))
+			return -1;
+		free(spec_arr[i].context);
+		spec_arr[i].context = tmpcon;
+		spec_arr[i].translated = 1;
+	}
+
 	*con = strdup(spec_arr[i].context);
 	if (!(*con))
 		return -1;
 
 	return 0;
 
-bad:
+      bad:
 	errno = EINVAL;
 	return -1;
 }
 
-int matchpathcon_index(const char *name, 
-		       mode_t mode,
-		       security_context_t *con)
+int matchpathcon_index(const char *name, mode_t mode, security_context_t * con)
 {
 	int i = matchpathcon_common(name, mode);
 
@@ -870,15 +882,91 @@ void matchpathcon_checkmatches(char *str)
 		if (spec_arr[i].matches == 0) {
 			if (spec_arr[i].type_str) {
 				myprintf
-					("%s:  Warning!  No matches for (%s, %s, %s)\n",
-					 str, spec_arr[i].regex_str,
-					 spec_arr[i].type_str, spec_arr[i].context);
+				    ("%s:  Warning!  No matches for (%s, %s, %s)\n",
+				     str, spec_arr[i].regex_str,
+				     spec_arr[i].type_str, spec_arr[i].context);
 			} else {
 				myprintf
-					("%s:  Warning!  No matches for (%s, %s)\n",
-					 str, spec_arr[i].regex_str,
-					 spec_arr[i].context);
+				    ("%s:  Warning!  No matches for (%s, %s)\n",
+				     str, spec_arr[i].regex_str,
+				     spec_arr[i].context);
 			}
 		}
 	}
 }
+
+/* Compare two contexts to see if their differences are "significant",
+ * or whether the only difference is in the user. */
+int selinux_file_context_cmp(const security_context_t a,
+			     const security_context_t b)
+{
+	char *rest_a, *rest_b;	/* Rest of the context after the user */
+	if (!a && !b)
+		return 0;
+	if (!a)
+		return -1;
+	if (!b)
+		return 1;
+	rest_a = strchr((char *)a, ':');
+	rest_b = strchr((char *)b, ':');
+	if (!rest_a && !rest_b)
+		return 0;
+	if (!rest_a)
+		return -1;
+	if (!rest_b)
+		return 1;
+	return strcmp(rest_a, rest_b);
+}
+
+int selinux_file_context_verify(const char *path, mode_t mode)
+{
+	security_context_t con = NULL;
+	security_context_t fcontext = NULL;
+	unsigned int localflags = myflags;
+	int rc = 0;
+
+	rc = lgetfilecon_raw(path, &con);
+	if (rc == -1) {
+		if (errno != ENOTSUP)
+			return 1;
+		else
+			return 0;
+	}
+
+	set_matchpathcon_flags(myflags | MATCHPATHCON_NOTRANS);
+	if (matchpathcon(path, mode, &fcontext) != 0) {
+		if (errno != ENOENT)
+			rc = 1;
+		else
+			rc = 0;
+	} else
+		rc = (selinux_file_context_cmp(fcontext, con) == 0);
+	set_matchpathcon_flags(localflags);
+	freecon(con);
+	freecon(fcontext);
+	return rc;
+}
+
+int selinux_lsetfilecon_default(const char *path)
+{
+	struct stat st;
+	int rc = -1;
+	security_context_t scontext = NULL;
+	unsigned int localflags = myflags;
+	if (lstat(path, &st) != 0)
+		return rc;
+
+	set_matchpathcon_flags(myflags | MATCHPATHCON_NOTRANS);
+
+	/* If there's an error determining the context, or it has none, 
+	   return to allow default context */
+	if (matchpathcon(path, st.st_mode, &scontext)) {
+		if (errno == ENOENT)
+			rc = 0;
+	} else {
+		rc = lsetfilecon_raw(path, scontext);
+		freecon(scontext);
+	}
+	set_matchpathcon_flags(localflags);
+	return rc;
+}
